@@ -9,7 +9,7 @@ use integer;    # vroom vroom!
 use Carp ();
 use Scalar::Util qw(openhandle);
 
-our $VERSION = '5.905'; # TRIAL VERSION from OurPkgVersion
+our $VERSION = '5.906'; # TRIAL VERSION from OurPkgVersion
 
 #---------------------------------------------------------------------------
 # Make a 'DEBUG' constant...
@@ -40,7 +40,7 @@ BEGIN {
     }
     elsif ( $] < 5.00404 ) {
 
-        # Grudgingly accomodate ancient (pre-constant) versions.
+        # Grudgingly accommodate ancient (pre-constant) versions.
         eval 'sub DEBUG { $Debug } ';
     }
     elsif ( !$DEBUG ) {
@@ -490,7 +490,7 @@ sub warning {
             # Now maybe do a little dance to enforce P-strictness.
             # This seems like it should be integrated with the big
             # "ALL HOPE..." block, further below, but that doesn't
-            # seem feasable.
+            # seem feasible.
             if (    $self->{'_p_strict'}
                 and $HTML::TreeBuilder::isKnown{$tag}
                 and not $HTML::Tagset::is_Possible_Strict_P_Content{$tag} )
@@ -1074,7 +1074,7 @@ sub warning {
 
         my $ptag = ( my $p = $self->{'_pos'} || $self )->{'_tag'};
 
-        # $p and $ptag are sort-of stratch
+        # $p and $ptag are sort-of scratch
 
         if ( ref($tag) ) {
 
@@ -1253,7 +1253,7 @@ sub warning {
     #      and $children->[-1] =~ m<^\s+$>s # last node is all-WS
     #      and
     #        (
-    #         # has a tightable parent:
+    #         # has a tightenable parent:
     #         $HTML::TreeBuilder::canTighten{ $e_tag }
     #         or
     #          ( # has a tightenable left sibling:
@@ -1816,8 +1816,8 @@ HTML::TreeBuilder - Parser that builds a HTML syntax tree
 =head1 VERSION
 
 B<This is a development release for testing purposes only.>
-This document describes version 5.905 of
-HTML::TreeBuilder, released June 29, 2013
+This document describes version 5.906 of
+HTML::TreeBuilder, released July 13, 2013
 as part of L<HTML-Tree|HTML::Tree>.
 
 Methods & attributes introduced in version 4.0 or later are marked
@@ -1898,6 +1898,11 @@ have C<implicit_tags> set to false.)
 Default is true.
 
 Implicit elements have the L<HTML::Element/implicit> attribute set.
+If you set C<implicit_tags> to false, the resulting tree will have
+exactly one implicit element: the root C<< <html> >> tag.  That
+element will contain whatever tags you parsed, which might include an
+explicit C<< <html> >> tag (if there was one).  If you want just the
+parsed content, use C<< $tree->content_list >>.
 
 =head2 implicit_body_p_tag
 
@@ -2267,7 +2272,7 @@ You should not need to call any of the following methods directly.
 
 This method returns the class which will be used for new elements.  It
 defaults to HTML::Element, but can be overridden by subclassing or esoteric
-means best left to those will will read the source and then not complain when
+means best left to those that will read the source and then not complain when
 those esoteric means change.  (Just subclass.)
 
 =head2 comment
